@@ -1,11 +1,9 @@
+from c2cwsgiutils import stats
 import math
-import socket
-import time
 
 
 class Statistics(object):
-
-    def __init__(self, format='%f'):
+    def __init__(self, format="%f"):
         self.format = format
         self.n = 0
         self.sum = 0.0
@@ -23,9 +21,9 @@ class Statistics(object):
     def __str__(self):
         result = []
         if self.n:
-            result.append('/'.join(self.format % value for value in (self.minimum, self.mean, self.maximum)))
-        result.append('(n={0:d})'.format(self.n))
-        return ' '.join(result)
+            result.append("/".join(self.format % value for value in (self.minimum, self.mean, self.maximum)))
+        result.append("(n={0:d})".format(self.n))
+        return " ".join(result)
 
     @property
     def mean(self):
@@ -40,23 +38,9 @@ class Statistics(object):
         return math.sqrt(self.variance)
 
 
-class Statsd(object):
-
-    def __init__(self, prefix='tilecloud.', host='127.0.0.1', port=8125):
-        self.prefix = prefix
-        self.host = host
-        self.port = port
-        self.socket = socket.socket(socket.AF_INET, socket.SOCK_DGRAM)
-
-    def send(self, message):
-        self.socket.sendto(self.prefix + message, (self.host, self.port))
-
-
 class Benchmark(object):
-
-    def __init__(self, attr='benchmark', statsd=None):
+    def __init__(self, attr="benchmark"):
         self.attr = attr
-        self.statsd = statsd
         self.statisticss = {}
 
     def sample(self, key=None):
@@ -64,7 +48,7 @@ class Benchmark(object):
             if key in self.statisticss:
                 statistics = self.statisticss[key]
             else:
-                statistics = Statistics('%.3fs')
+                statistics = Statistics("%.3fs")
                 self.statisticss[key] = statistics
         else:
             statistics = None
@@ -72,36 +56,26 @@ class Benchmark(object):
         def callback(tile):
             if tile:
                 if hasattr(tile, self.attr):
-                    times = getattr(tile, self.attr)
-                    times.append(time.time())
-                    delta_t = times[-1] - times[-2]
+                    timer = getattr(tile, self.attr)
+                    delta_t = timer.stop()
                     if statistics:
                         statistics.add(delta_t)
-                    if self.statsd:
-                        self.statsd.send('{0!s}:{1:.3f}|ms'.format(key, delta_t))
                 else:
-                    setattr(tile, self.attr, [time.time()])
+                    setattr(tile, self.attr, stats.timer([key]))
             return tile
+
         return callback
 
 
 class StatsdCountTiles(object):
-
-    def __init__(self, statsd):
-        self.statsd = statsd
-
     def __call__(self, tile):
         if tile:
-            self.statsd.send('tiles:1|c')
+            stats.increment_counter(["tiles"])
         return tile
 
 
 class StatsdCountErrors(object):
-
-    def __init__(self, statsd):
-        self.statsd = statsd
-
     def __call__(self, tile):
         if tile and tile.error:
-            self.statsd.send('errors:1|c')
+            stats.increment_counter(["errors"])
         return tile
