@@ -57,7 +57,7 @@ class MaximumConsecutiveErrors(object):
         self.consecutive_errors = 0
 
     def __call__(self, tile):
-        if tile.error:
+        if tile and tile.error:
             self.consecutive_errors += 1
             if self.consecutive_errors > self.max_consecutive_errors:
                 raise TooManyErrors
@@ -89,8 +89,10 @@ class MaximumErrorRate(object):
         self.tile_count += 1
         if tile and tile.error:
             self.error_count += 1
-            if self.tile_count >= self.min_tiles and \
-               self.error_count >= self.max_error_rate * self.tile_count:
+            if (
+                self.tile_count >= self.min_tiles
+                and self.error_count >= self.max_error_rate * self.tile_count
+            ):
                 raise TooManyErrors
         return tile
 
@@ -119,4 +121,5 @@ class MaximumErrors(object):
 
 class TooManyErrors(RuntimeError):
     """TooManyErrors exception class."""
+
     pass
