@@ -1,5 +1,5 @@
 from gzip import GzipFile
-from six.moves import cStringIO as StringIO
+from io import StringIO
 
 
 class GzipCompressor(object):
@@ -18,12 +18,10 @@ class GzipCompressor(object):
         assert tile.data is not None
         assert tile.content_encoding is None
         string_io = StringIO()
-        gzip_file = GzipFile(compresslevel=self.compresslevel,
-                             fileobj=string_io,
-                             mode='w')
+        gzip_file = GzipFile(compresslevel=self.compresslevel, fileobj=string_io, mode="w")
         gzip_file.write(tile.data)
         gzip_file.close()
-        tile.content_encoding = 'gzip'
+        tile.content_encoding = "gzip"
         tile.data = string_io.getvalue()
         return tile
 
@@ -35,7 +33,7 @@ class GzipDecompressor(object):
 
     def __call__(self, tile):
         assert tile.data is not None
-        if tile.content_encoding == 'gzip':
+        if tile.content_encoding == "gzip":
             tile.content_encoding = None
             tile.data = GzipFile(fileobj=StringIO(tile.data)).read()
         return tile
