@@ -2,16 +2,13 @@
 This module includes filters doing manipulations on the tile image. It
 requires the PIL lib.
 """
-from cStringIO import StringIO
+
+from io import StringIO
 
 import PIL.Image
 
 from tilecloud import Tile
-
-
-FORMAT_BY_CONTENT_TYPE = {
-        'image/jpeg': 'JPEG',
-        'image/png': 'PNG'}
+from tilecloud.lib.PIL_ import FORMAT_BY_CONTENT_TYPE
 
 
 class ImageFormatConverter(object):
@@ -35,8 +32,7 @@ class ImageFormatConverter(object):
         if tile.content_type != self.content_type:
             assert tile.data is not None
             string_io = StringIO()
-            PIL.Image.open(StringIO(tile.data)).save(string_io, self.format,
-                           **self.kwargs)
+            PIL.Image.open(StringIO(tile.data)).save(string_io, self.format, **self.kwargs)
             tile.content_type = self.content_type
             tile.data = string_io.getvalue()
         return tile
@@ -73,8 +69,7 @@ class MergeFilter(object):
         if content_type is None:
             self.content_type = tile.content_type
         string_io = StringIO()
-        image.save(string_io, FORMAT_BY_CONTENT_TYPE[content_type],
-                   **self.kwargs)
+        image.save(string_io, FORMAT_BY_CONTENT_TYPE[content_type], **self.kwargs)
         tile.content_type = content_type
         tile.data = string_io.getvalue()
         return tile
@@ -101,8 +96,6 @@ class PILImageFilter(object):
         image = PIL.Image.open(StringIO(tile.data))
         image = image.filter(self.filter)
         string_io = StringIO()
-        image.save(string_io,
-                   FORMAT_BY_CONTENT_TYPE.get(tile.content_type, 'PNG'),
-                   **self.kwargs)
+        image.save(string_io, FORMAT_BY_CONTENT_TYPE.get(tile.content_type, "PNG"), **self.kwargs)
         tile.data = string_io.getvalue()
         return tile
