@@ -12,17 +12,19 @@ CLIENT_TIMEOUT = 60
 class S3TileStore(TileStore):
     """Tiles stored in Amazon S3"""
 
-    def __init__(self, bucket, tilelayout, dry_run=False, s3_host=None, **kwargs):
-        self.client = get_client(s3_host)
+    def __init__(self, bucket, tilelayout, dry_run=False, s3_host=None, cache_control=None, **kwargs):
+        self._s3_host = s3_host
+        self._client = None
         self.bucket = bucket
         self.tilelayout = tilelayout
         self.dry_run = dry_run
+        self.cache_control = cache_control
         TileStore.__init__(self, **kwargs)
 
     def __contains__(self, tile):
         if not tile:
             return False
-        key_name = self.tilelayout.filename(tile.tilecoord)
+        key_name = self.tilelayout.filename(tile.tilecoord, tile.metadata)
         try:
             self.client.head_object(Bucket=self.bucket, Key=key_name)
             return True
@@ -34,7 +36,7 @@ class S3TileStore(TileStore):
 
     def delete_one(self, tile):
         try:
-            key_name = self.tilelayout.filename(tile.tilecoord)
+            key_name = self.tilelayout.filename(tile.tilecoord, tile.metadata)
             if not self.dry_run:
                 self.client.delete_object(Bucket=self.bucket, Key=key_name)
         except botocore.exceptions.ClientError as exc:
@@ -42,12 +44,12 @@ class S3TileStore(TileStore):
         return tile
 
     def get_one(self, tile):
-        key_name = self.tilelayout.filename(tile.tilecoord)
+        key_name = self.tilelayout.filename(tile.tilecoord, tile.metadata)
         try:
             response = self.client.get_object(Bucket=self.bucket, Key=key_name)
-            tile.data = response['Body'].read()
-            tile.content_encoding = response.get('ContentEncoding')
-            tile.content_type = response.get('ContentType')
+            tile.data = response["Body"].read()
+            tile.content_encoding = response.get("ContentEncoding")
+            tile.content_type = response.get("ContentType")
         except botocore.exceptions.ClientError as exc:
             if _get_status(exc) == 404:
                 return None
@@ -56,37 +58,46 @@ class S3TileStore(TileStore):
         return tile
 
     def list(self):
-        prefix = getattr(self.tilelayout, 'prefix', '')
+        prefix = getattr(self.tilelayout, "prefix", "")
         for s3_key in self.client.list_objects(Bucket=self.bucket, Prefix=prefix):
             try:
-                tilecoord = self.tilelayout.tilecoord(s3_key['Key'])
+                tilecoord = self.tilelayout.tilecoord(s3_key["Key"])
             except ValueError:
                 continue
             yield Tile(tilecoord)
 
     def put_one(self, tile):
         assert tile.data is not None
-        key_name = self.tilelayout.filename(tile.tilecoord)
+        key_name = self.tilelayout.filename(tile.tilecoord, tile.metadata)
         args = {}
         if tile.content_encoding is not None:
-            args['ContentEncoding'] = tile.content_encoding
+            args["ContentEncoding"] = tile.content_encoding
         if tile.content_type is not None:
-            args['ContentType'] = tile.content_type
+            args["ContentType"] = tile.content_type
+        if self.cache_control is not None:
+            args["CacheControl"] = self.cache_control
         if not self.dry_run:
             try:
-                self.client.put_object(ACL='public-read', Body=tile.data, Key=key_name, Bucket=self.bucket,
-                                       **args)
+                self.client.put_object(
+                    ACL="public-read", Body=tile.data, Key=key_name, Bucket=self.bucket, **args
+                )
             except botocore.exceptions.ClientError as exc:
                 tile.error = exc
         return tile
 
+    @property
+    def client(self):
+        if self._client is None:
+            self._client = get_client(self._s3_host)
+        return self._client
+
 
 def _get_status(s3_client_exception):
-    return int(s3_client_exception.response['Error']['Code'])
+    return s3_client_exception.response["ResponseMetadata"]["HTTPStatusCode"]
 
 
 def get_client(s3_host):
     config = botocore.config.Config(connect_timeout=CLIENT_TIMEOUT, read_timeout=CLIENT_TIMEOUT)
-    session = boto3.session.Session()
-    return session.client('s3', endpoint_url=('https://%s/' % s3_host) if s3_host is not None else None,
-                          config=config)
+    return boto3.client(
+        "s3", endpoint_url=("https://%s/" % s3_host) if s3_host is not None else None, config=config
+    )
