@@ -10,7 +10,6 @@ from tilecloud.layout.wrapped import WrappedTileLayout
 
 
 class ZipTileStore(TileStore):
-
     def __init__(self, zipfile, layout=None, **kwargs):
         TileStore.__init__(self, **kwargs)
         self.zipfile = zipfile
@@ -19,8 +18,10 @@ class ZipTileStore(TileStore):
             extension_count = defaultdict(int)
             for name in self.zipfile.namelist():
                 extension_count[os.path.splitext(name)[1]] += 1
-            for extension, count in sorted(extension_count.items(), key=lambda p: tuple(reversed(p)), reverse=True):
-                if re.match(r'\.(jpe?g|png)\Z', extension, re.I):
+            for extension, _ in sorted(
+                extension_count.items(), key=lambda p: tuple(reversed(p)), reverse=True
+            ):
+                if re.match(r"\.(jpe?g|png)\Z", extension, re.I):
                     self.layout = WrappedTileLayout(OSMTileLayout(), suffix=extension)
                     break
         if self.layout is None:
@@ -30,17 +31,17 @@ class ZipTileStore(TileStore):
         if not tile:
             return False
         try:
-            filename = self.layout.filename(tile.tilecoord)
+            filename = self.layout.filename(tile.tilecoord, tile.metadata)
             self.zipfile.getinfo(filename)
             return True
         except KeyError:
             return False
 
     def get_one(self, tile):
-        if hasattr(tile, 'zipinfo'):
+        if hasattr(tile, "zipinfo"):
             tile.data = self.zipfile.read(tile.zipinfo)
         else:
-            filename = self.layout.filename(tile.tilecoord)
+            filename = self.layout.filename(tile.tilecoord, tile.metadata)
             tile.data = self.zipfile.read(filename)
         return tile
 
@@ -52,9 +53,9 @@ class ZipTileStore(TileStore):
                 pass
 
     def put_one(self, tile):
-        filename = self.layout.filename(tile.tilecoord)
+        filename = self.layout.filename(tile.tilecoord, tile.metadata)
         zipinfo = zipfile.ZipInfo(filename)
-        zipinfo.compress_type = getattr(self, 'compress_type', zipfile.ZIP_DEFLATED)
+        zipinfo.compress_type = getattr(self, "compress_type", zipfile.ZIP_DEFLATED)
         zipinfo.date_time = datetime.now().timetuple()[:6]
         zipinfo.external_attr = 0o644 << 16
         self.zipfile.writestr(zipinfo, tile.data)
